@@ -3,15 +3,15 @@
 
 /*
  * SPDX-License-Identifier: Apache-2.0
- * Copyright (C) 2020 Raspberry Pi Ltd
+ * Copyright (C) 2020-2025 Raspberry Pi Ltd
  */
 
 
 /* Repository URL */
-#define OSLIST_URL                        "https://downloads.raspberrypi.org/os_list_imagingutility_v4.json"
+#define OSLIST_URL                        "https://downloads.raspberrypi.com/os_list_imagingutility_v4.json"
 
-/* Time synchronization URL (only used on eglfs QPA platform, URL must be HTTP) */
-#define TIME_URL                          "http://downloads.raspberrypi.org/os_list_imagingutility_v4.json?time_synchronization"
+/* Time synchronization URL (only used on linuxfb QPA platform, URL must be HTTP) */
+#define TIME_URL                          "http://downloads.raspberrypi.com/"
 
 /* Phone home the name of images downloaded for image popularity ranking */
 #define TELEMETRY_URL                     "https://rpi-imager-stats.raspberrypi.com/downloads"
